@@ -22,6 +22,12 @@ our %return_counts = (
         'fids_to_co_occurring_fids' => 1,
         'fids_to_locations' => 1,
         'locations_to_fids' => 1,
+        'alleles_to_bp_locs' => 1,
+        'region_to_fids' => 1,
+        'region_to_alleles' => 1,
+        'alleles_to_traits' => 1,
+        'traits_to_alleles' => 1,
+        'ous_with_trait' => 1,
         'locations_to_dna_sequences' => 1,
         'proteins_to_fids' => 1,
         'proteins_to_protein_families' => 1,
@@ -72,96 +78,158 @@ our %return_counts = (
         'otu_members' => 1,
         'fids_to_genomes' => 1,
         'text_search' => 1,
+        'corresponds' => 1,
+        'corresponds_from_sequences' => 1,
+        'close_genomes' => 1,
+        'representative_sequences' => 2,
+        'align_sequences' => 1,
         'get_entity_AlignmentTree' => 1,
+        'query_entity_AlignmentTree' => 1,
         'all_entities_AlignmentTree' => 1,
+        'get_entity_AlleleFrequency' => 1,
+        'query_entity_AlleleFrequency' => 1,
+        'all_entities_AlleleFrequency' => 1,
         'get_entity_Annotation' => 1,
+        'query_entity_Annotation' => 1,
         'all_entities_Annotation' => 1,
+        'get_entity_Assay' => 1,
+        'query_entity_Assay' => 1,
+        'all_entities_Assay' => 1,
         'get_entity_AtomicRegulon' => 1,
+        'query_entity_AtomicRegulon' => 1,
         'all_entities_AtomicRegulon' => 1,
         'get_entity_Attribute' => 1,
+        'query_entity_Attribute' => 1,
         'all_entities_Attribute' => 1,
         'get_entity_Biomass' => 1,
+        'query_entity_Biomass' => 1,
         'all_entities_Biomass' => 1,
         'get_entity_BiomassCompound' => 1,
+        'query_entity_BiomassCompound' => 1,
         'all_entities_BiomassCompound' => 1,
         'get_entity_Compartment' => 1,
+        'query_entity_Compartment' => 1,
         'all_entities_Compartment' => 1,
         'get_entity_Complex' => 1,
+        'query_entity_Complex' => 1,
         'all_entities_Complex' => 1,
         'get_entity_Compound' => 1,
+        'query_entity_Compound' => 1,
         'all_entities_Compound' => 1,
         'get_entity_Contig' => 1,
+        'query_entity_Contig' => 1,
         'all_entities_Contig' => 1,
         'get_entity_ContigChunk' => 1,
+        'query_entity_ContigChunk' => 1,
         'all_entities_ContigChunk' => 1,
         'get_entity_ContigSequence' => 1,
+        'query_entity_ContigSequence' => 1,
         'all_entities_ContigSequence' => 1,
         'get_entity_CoregulatedSet' => 1,
+        'query_entity_CoregulatedSet' => 1,
         'all_entities_CoregulatedSet' => 1,
         'get_entity_Diagram' => 1,
+        'query_entity_Diagram' => 1,
         'all_entities_Diagram' => 1,
         'get_entity_EcNumber' => 1,
+        'query_entity_EcNumber' => 1,
         'all_entities_EcNumber' => 1,
         'get_entity_Experiment' => 1,
+        'query_entity_Experiment' => 1,
         'all_entities_Experiment' => 1,
         'get_entity_Family' => 1,
+        'query_entity_Family' => 1,
         'all_entities_Family' => 1,
         'get_entity_Feature' => 1,
+        'query_entity_Feature' => 1,
         'all_entities_Feature' => 1,
         'get_entity_Genome' => 1,
+        'query_entity_Genome' => 1,
         'all_entities_Genome' => 1,
-        'get_entity_Identifier' => 1,
-        'all_entities_Identifier' => 1,
+        'get_entity_Locality' => 1,
+        'query_entity_Locality' => 1,
+        'all_entities_Locality' => 1,
         'get_entity_Media' => 1,
+        'query_entity_Media' => 1,
         'all_entities_Media' => 1,
         'get_entity_Model' => 1,
+        'query_entity_Model' => 1,
         'all_entities_Model' => 1,
         'get_entity_ModelCompartment' => 1,
+        'query_entity_ModelCompartment' => 1,
         'all_entities_ModelCompartment' => 1,
         'get_entity_OTU' => 1,
+        'query_entity_OTU' => 1,
         'all_entities_OTU' => 1,
+        'get_entity_ObservationalUnit' => 1,
+        'query_entity_ObservationalUnit' => 1,
+        'all_entities_ObservationalUnit' => 1,
         'get_entity_PairSet' => 1,
+        'query_entity_PairSet' => 1,
         'all_entities_PairSet' => 1,
         'get_entity_Pairing' => 1,
+        'query_entity_Pairing' => 1,
         'all_entities_Pairing' => 1,
         'get_entity_ProbeSet' => 1,
+        'query_entity_ProbeSet' => 1,
         'all_entities_ProbeSet' => 1,
         'get_entity_ProteinSequence' => 1,
+        'query_entity_ProteinSequence' => 1,
         'all_entities_ProteinSequence' => 1,
         'get_entity_Publication' => 1,
+        'query_entity_Publication' => 1,
         'all_entities_Publication' => 1,
         'get_entity_Reaction' => 1,
+        'query_entity_Reaction' => 1,
         'all_entities_Reaction' => 1,
         'get_entity_ReactionRule' => 1,
+        'query_entity_ReactionRule' => 1,
         'all_entities_ReactionRule' => 1,
         'get_entity_Reagent' => 1,
+        'query_entity_Reagent' => 1,
         'all_entities_Reagent' => 1,
         'get_entity_Requirement' => 1,
+        'query_entity_Requirement' => 1,
         'all_entities_Requirement' => 1,
         'get_entity_Role' => 1,
+        'query_entity_Role' => 1,
         'all_entities_Role' => 1,
         'get_entity_SSCell' => 1,
+        'query_entity_SSCell' => 1,
         'all_entities_SSCell' => 1,
         'get_entity_SSRow' => 1,
+        'query_entity_SSRow' => 1,
         'all_entities_SSRow' => 1,
         'get_entity_Scenario' => 1,
+        'query_entity_Scenario' => 1,
         'all_entities_Scenario' => 1,
         'get_entity_Source' => 1,
+        'query_entity_Source' => 1,
         'all_entities_Source' => 1,
+        'get_entity_StudyExperiment' => 1,
+        'query_entity_StudyExperiment' => 1,
+        'all_entities_StudyExperiment' => 1,
         'get_entity_Subsystem' => 1,
+        'query_entity_Subsystem' => 1,
         'all_entities_Subsystem' => 1,
         'get_entity_SubsystemClass' => 1,
+        'query_entity_SubsystemClass' => 1,
         'all_entities_SubsystemClass' => 1,
         'get_entity_TaxonomicGrouping' => 1,
+        'query_entity_TaxonomicGrouping' => 1,
         'all_entities_TaxonomicGrouping' => 1,
+        'get_entity_Trait' => 1,
+        'query_entity_Trait' => 1,
+        'all_entities_Trait' => 1,
         'get_entity_Variant' => 1,
+        'query_entity_Variant' => 1,
         'all_entities_Variant' => 1,
-        'get_entity_Variation' => 1,
-        'all_entities_Variation' => 1,
         'get_relationship_AffectsLevelOf' => 1,
         'get_relationship_IsAffectedIn' => 1,
         'get_relationship_Aligns' => 1,
         'get_relationship_IsAlignedBy' => 1,
+        'get_relationship_AssertsFunctionFor' => 1,
+        'get_relationship_HasAssertedFunctionFrom' => 1,
         'get_relationship_Concerns' => 1,
         'get_relationship_IsATopicOf' => 1,
         'get_relationship_Contains' => 1,
@@ -178,8 +246,6 @@ our %return_counts = (
         'get_relationship_WasFormulatedBy' => 1,
         'get_relationship_GeneratedLevelsFor' => 1,
         'get_relationship_WasGeneratedFrom' => 1,
-        'get_relationship_HasAssertionFrom' => 1,
-        'get_relationship_Asserts' => 1,
         'get_relationship_HasCompoundAliasFrom' => 1,
         'get_relationship_UsesAliasForCompound' => 1,
         'get_relationship_HasIndicatedSignalFrom' => 1,
@@ -190,6 +256,8 @@ our %return_counts = (
         'get_relationship_ParticipatesIn' => 1,
         'get_relationship_HasPresenceOf' => 1,
         'get_relationship_IsPresentIn' => 1,
+        'get_relationship_HasProteinMember' => 1,
+        'get_relationship_IsProteinMemberOf' => 1,
         'get_relationship_HasReactionAliasFrom' => 1,
         'get_relationship_UsesAliasForReaction' => 1,
         'get_relationship_HasRepresentativeOf' => 1,
@@ -200,26 +268,32 @@ our %return_counts = (
         'get_relationship_IsSectionOf' => 1,
         'get_relationship_HasStep' => 1,
         'get_relationship_IsStepOf' => 1,
+        'get_relationship_HasTrait' => 1,
+        'get_relationship_Measures' => 1,
+        'get_relationship_HasUnits' => 1,
+        'get_relationship_IsLocated' => 1,
         'get_relationship_HasUsage' => 1,
         'get_relationship_IsUsageOf' => 1,
         'get_relationship_HasValueFor' => 1,
         'get_relationship_HasValueIn' => 1,
-        'get_relationship_Imported' => 1,
-        'get_relationship_WasImportedFrom' => 1,
+        'get_relationship_HasVariationIn' => 1,
+        'get_relationship_IsVariedIn' => 1,
+        'get_relationship_Impacts' => 1,
+        'get_relationship_IsImpactedBy' => 1,
         'get_relationship_Includes' => 1,
         'get_relationship_IsIncludedIn' => 1,
+        'get_relationship_IncludesPart' => 1,
+        'get_relationship_IsPartOf' => 1,
         'get_relationship_IndicatedLevelsFor' => 1,
         'get_relationship_HasLevelsFrom' => 1,
         'get_relationship_Involves' => 1,
         'get_relationship_IsInvolvedIn' => 1,
         'get_relationship_IsARequirementIn' => 1,
         'get_relationship_IsARequirementOf' => 1,
-        'get_relationship_IsAlignedIn' => 1,
-        'get_relationship_IsAlignmentFor' => 1,
         'get_relationship_IsAnnotatedBy' => 1,
         'get_relationship_Annotates' => 1,
-        'get_relationship_IsBindingSiteFor' => 1,
-        'get_relationship_IsBoundBy' => 1,
+        'get_relationship_IsAssayOf' => 1,
+        'get_relationship_IsAssayedBy' => 1,
         'get_relationship_IsClassFor' => 1,
         'get_relationship_IsInClass' => 1,
         'get_relationship_IsCollectionOf' => 1,
@@ -264,8 +338,6 @@ our %return_counts = (
         'get_relationship_IsLocusFor' => 1,
         'get_relationship_IsModeledBy' => 1,
         'get_relationship_Models' => 1,
-        'get_relationship_IsNamedBy' => 1,
-        'get_relationship_Names' => 1,
         'get_relationship_IsOwnerOf' => 1,
         'get_relationship_IsOwnedBy' => 1,
         'get_relationship_IsProposedLocationOf' => 1,
@@ -274,10 +346,14 @@ our %return_counts = (
         'get_relationship_Produces' => 1,
         'get_relationship_IsRealLocationOf' => 1,
         'get_relationship_HasRealLocationIn' => 1,
+        'get_relationship_IsReferencedBy' => 1,
+        'get_relationship_UsesReference' => 1,
         'get_relationship_IsRegulatedIn' => 1,
         'get_relationship_IsRegulatedSetOf' => 1,
         'get_relationship_IsRelevantFor' => 1,
         'get_relationship_IsRelevantTo' => 1,
+        'get_relationship_IsRepresentedBy' => 1,
+        'get_relationship_DefinedBy' => 1,
         'get_relationship_IsRequiredBy' => 1,
         'get_relationship_Requires' => 1,
         'get_relationship_IsRoleOf' => 1,
@@ -288,6 +364,8 @@ our %return_counts = (
         'get_relationship_HasAsSequence' => 1,
         'get_relationship_IsSubInstanceOf' => 1,
         'get_relationship_Validates' => 1,
+        'get_relationship_IsSummarizedBy' => 1,
+        'get_relationship_Summarizes' => 1,
         'get_relationship_IsSuperclassOf' => 1,
         'get_relationship_IsSubclassOf' => 1,
         'get_relationship_IsTargetOf' => 1,
@@ -335,6 +413,12 @@ sub _build_valid_methods
         'fids_to_co_occurring_fids' => 1,
         'fids_to_locations' => 1,
         'locations_to_fids' => 1,
+        'alleles_to_bp_locs' => 1,
+        'region_to_fids' => 1,
+        'region_to_alleles' => 1,
+        'alleles_to_traits' => 1,
+        'traits_to_alleles' => 1,
+        'ous_with_trait' => 1,
         'locations_to_dna_sequences' => 1,
         'proteins_to_fids' => 1,
         'proteins_to_protein_families' => 1,
@@ -385,96 +469,158 @@ sub _build_valid_methods
         'otu_members' => 1,
         'fids_to_genomes' => 1,
         'text_search' => 1,
+        'corresponds' => 1,
+        'corresponds_from_sequences' => 1,
+        'close_genomes' => 1,
+        'representative_sequences' => 1,
+        'align_sequences' => 1,
         'get_entity_AlignmentTree' => 1,
+        'query_entity_AlignmentTree' => 1,
         'all_entities_AlignmentTree' => 1,
+        'get_entity_AlleleFrequency' => 1,
+        'query_entity_AlleleFrequency' => 1,
+        'all_entities_AlleleFrequency' => 1,
         'get_entity_Annotation' => 1,
+        'query_entity_Annotation' => 1,
         'all_entities_Annotation' => 1,
+        'get_entity_Assay' => 1,
+        'query_entity_Assay' => 1,
+        'all_entities_Assay' => 1,
         'get_entity_AtomicRegulon' => 1,
+        'query_entity_AtomicRegulon' => 1,
         'all_entities_AtomicRegulon' => 1,
         'get_entity_Attribute' => 1,
+        'query_entity_Attribute' => 1,
         'all_entities_Attribute' => 1,
         'get_entity_Biomass' => 1,
+        'query_entity_Biomass' => 1,
         'all_entities_Biomass' => 1,
         'get_entity_BiomassCompound' => 1,
+        'query_entity_BiomassCompound' => 1,
         'all_entities_BiomassCompound' => 1,
         'get_entity_Compartment' => 1,
+        'query_entity_Compartment' => 1,
         'all_entities_Compartment' => 1,
         'get_entity_Complex' => 1,
+        'query_entity_Complex' => 1,
         'all_entities_Complex' => 1,
         'get_entity_Compound' => 1,
+        'query_entity_Compound' => 1,
         'all_entities_Compound' => 1,
         'get_entity_Contig' => 1,
+        'query_entity_Contig' => 1,
         'all_entities_Contig' => 1,
         'get_entity_ContigChunk' => 1,
+        'query_entity_ContigChunk' => 1,
         'all_entities_ContigChunk' => 1,
         'get_entity_ContigSequence' => 1,
+        'query_entity_ContigSequence' => 1,
         'all_entities_ContigSequence' => 1,
         'get_entity_CoregulatedSet' => 1,
+        'query_entity_CoregulatedSet' => 1,
         'all_entities_CoregulatedSet' => 1,
         'get_entity_Diagram' => 1,
+        'query_entity_Diagram' => 1,
         'all_entities_Diagram' => 1,
         'get_entity_EcNumber' => 1,
+        'query_entity_EcNumber' => 1,
         'all_entities_EcNumber' => 1,
         'get_entity_Experiment' => 1,
+        'query_entity_Experiment' => 1,
         'all_entities_Experiment' => 1,
         'get_entity_Family' => 1,
+        'query_entity_Family' => 1,
         'all_entities_Family' => 1,
         'get_entity_Feature' => 1,
+        'query_entity_Feature' => 1,
         'all_entities_Feature' => 1,
         'get_entity_Genome' => 1,
+        'query_entity_Genome' => 1,
         'all_entities_Genome' => 1,
-        'get_entity_Identifier' => 1,
-        'all_entities_Identifier' => 1,
+        'get_entity_Locality' => 1,
+        'query_entity_Locality' => 1,
+        'all_entities_Locality' => 1,
         'get_entity_Media' => 1,
+        'query_entity_Media' => 1,
         'all_entities_Media' => 1,
         'get_entity_Model' => 1,
+        'query_entity_Model' => 1,
         'all_entities_Model' => 1,
         'get_entity_ModelCompartment' => 1,
+        'query_entity_ModelCompartment' => 1,
         'all_entities_ModelCompartment' => 1,
         'get_entity_OTU' => 1,
+        'query_entity_OTU' => 1,
         'all_entities_OTU' => 1,
+        'get_entity_ObservationalUnit' => 1,
+        'query_entity_ObservationalUnit' => 1,
+        'all_entities_ObservationalUnit' => 1,
         'get_entity_PairSet' => 1,
+        'query_entity_PairSet' => 1,
         'all_entities_PairSet' => 1,
         'get_entity_Pairing' => 1,
+        'query_entity_Pairing' => 1,
         'all_entities_Pairing' => 1,
         'get_entity_ProbeSet' => 1,
+        'query_entity_ProbeSet' => 1,
         'all_entities_ProbeSet' => 1,
         'get_entity_ProteinSequence' => 1,
+        'query_entity_ProteinSequence' => 1,
         'all_entities_ProteinSequence' => 1,
         'get_entity_Publication' => 1,
+        'query_entity_Publication' => 1,
         'all_entities_Publication' => 1,
         'get_entity_Reaction' => 1,
+        'query_entity_Reaction' => 1,
         'all_entities_Reaction' => 1,
         'get_entity_ReactionRule' => 1,
+        'query_entity_ReactionRule' => 1,
         'all_entities_ReactionRule' => 1,
         'get_entity_Reagent' => 1,
+        'query_entity_Reagent' => 1,
         'all_entities_Reagent' => 1,
         'get_entity_Requirement' => 1,
+        'query_entity_Requirement' => 1,
         'all_entities_Requirement' => 1,
         'get_entity_Role' => 1,
+        'query_entity_Role' => 1,
         'all_entities_Role' => 1,
         'get_entity_SSCell' => 1,
+        'query_entity_SSCell' => 1,
         'all_entities_SSCell' => 1,
         'get_entity_SSRow' => 1,
+        'query_entity_SSRow' => 1,
         'all_entities_SSRow' => 1,
         'get_entity_Scenario' => 1,
+        'query_entity_Scenario' => 1,
         'all_entities_Scenario' => 1,
         'get_entity_Source' => 1,
+        'query_entity_Source' => 1,
         'all_entities_Source' => 1,
+        'get_entity_StudyExperiment' => 1,
+        'query_entity_StudyExperiment' => 1,
+        'all_entities_StudyExperiment' => 1,
         'get_entity_Subsystem' => 1,
+        'query_entity_Subsystem' => 1,
         'all_entities_Subsystem' => 1,
         'get_entity_SubsystemClass' => 1,
+        'query_entity_SubsystemClass' => 1,
         'all_entities_SubsystemClass' => 1,
         'get_entity_TaxonomicGrouping' => 1,
+        'query_entity_TaxonomicGrouping' => 1,
         'all_entities_TaxonomicGrouping' => 1,
+        'get_entity_Trait' => 1,
+        'query_entity_Trait' => 1,
+        'all_entities_Trait' => 1,
         'get_entity_Variant' => 1,
+        'query_entity_Variant' => 1,
         'all_entities_Variant' => 1,
-        'get_entity_Variation' => 1,
-        'all_entities_Variation' => 1,
         'get_relationship_AffectsLevelOf' => 1,
         'get_relationship_IsAffectedIn' => 1,
         'get_relationship_Aligns' => 1,
         'get_relationship_IsAlignedBy' => 1,
+        'get_relationship_AssertsFunctionFor' => 1,
+        'get_relationship_HasAssertedFunctionFrom' => 1,
         'get_relationship_Concerns' => 1,
         'get_relationship_IsATopicOf' => 1,
         'get_relationship_Contains' => 1,
@@ -491,8 +637,6 @@ sub _build_valid_methods
         'get_relationship_WasFormulatedBy' => 1,
         'get_relationship_GeneratedLevelsFor' => 1,
         'get_relationship_WasGeneratedFrom' => 1,
-        'get_relationship_HasAssertionFrom' => 1,
-        'get_relationship_Asserts' => 1,
         'get_relationship_HasCompoundAliasFrom' => 1,
         'get_relationship_UsesAliasForCompound' => 1,
         'get_relationship_HasIndicatedSignalFrom' => 1,
@@ -503,6 +647,8 @@ sub _build_valid_methods
         'get_relationship_ParticipatesIn' => 1,
         'get_relationship_HasPresenceOf' => 1,
         'get_relationship_IsPresentIn' => 1,
+        'get_relationship_HasProteinMember' => 1,
+        'get_relationship_IsProteinMemberOf' => 1,
         'get_relationship_HasReactionAliasFrom' => 1,
         'get_relationship_UsesAliasForReaction' => 1,
         'get_relationship_HasRepresentativeOf' => 1,
@@ -513,26 +659,32 @@ sub _build_valid_methods
         'get_relationship_IsSectionOf' => 1,
         'get_relationship_HasStep' => 1,
         'get_relationship_IsStepOf' => 1,
+        'get_relationship_HasTrait' => 1,
+        'get_relationship_Measures' => 1,
+        'get_relationship_HasUnits' => 1,
+        'get_relationship_IsLocated' => 1,
         'get_relationship_HasUsage' => 1,
         'get_relationship_IsUsageOf' => 1,
         'get_relationship_HasValueFor' => 1,
         'get_relationship_HasValueIn' => 1,
-        'get_relationship_Imported' => 1,
-        'get_relationship_WasImportedFrom' => 1,
+        'get_relationship_HasVariationIn' => 1,
+        'get_relationship_IsVariedIn' => 1,
+        'get_relationship_Impacts' => 1,
+        'get_relationship_IsImpactedBy' => 1,
         'get_relationship_Includes' => 1,
         'get_relationship_IsIncludedIn' => 1,
+        'get_relationship_IncludesPart' => 1,
+        'get_relationship_IsPartOf' => 1,
         'get_relationship_IndicatedLevelsFor' => 1,
         'get_relationship_HasLevelsFrom' => 1,
         'get_relationship_Involves' => 1,
         'get_relationship_IsInvolvedIn' => 1,
         'get_relationship_IsARequirementIn' => 1,
         'get_relationship_IsARequirementOf' => 1,
-        'get_relationship_IsAlignedIn' => 1,
-        'get_relationship_IsAlignmentFor' => 1,
         'get_relationship_IsAnnotatedBy' => 1,
         'get_relationship_Annotates' => 1,
-        'get_relationship_IsBindingSiteFor' => 1,
-        'get_relationship_IsBoundBy' => 1,
+        'get_relationship_IsAssayOf' => 1,
+        'get_relationship_IsAssayedBy' => 1,
         'get_relationship_IsClassFor' => 1,
         'get_relationship_IsInClass' => 1,
         'get_relationship_IsCollectionOf' => 1,
@@ -577,8 +729,6 @@ sub _build_valid_methods
         'get_relationship_IsLocusFor' => 1,
         'get_relationship_IsModeledBy' => 1,
         'get_relationship_Models' => 1,
-        'get_relationship_IsNamedBy' => 1,
-        'get_relationship_Names' => 1,
         'get_relationship_IsOwnerOf' => 1,
         'get_relationship_IsOwnedBy' => 1,
         'get_relationship_IsProposedLocationOf' => 1,
@@ -587,10 +737,14 @@ sub _build_valid_methods
         'get_relationship_Produces' => 1,
         'get_relationship_IsRealLocationOf' => 1,
         'get_relationship_HasRealLocationIn' => 1,
+        'get_relationship_IsReferencedBy' => 1,
+        'get_relationship_UsesReference' => 1,
         'get_relationship_IsRegulatedIn' => 1,
         'get_relationship_IsRegulatedSetOf' => 1,
         'get_relationship_IsRelevantFor' => 1,
         'get_relationship_IsRelevantTo' => 1,
+        'get_relationship_IsRepresentedBy' => 1,
+        'get_relationship_DefinedBy' => 1,
         'get_relationship_IsRequiredBy' => 1,
         'get_relationship_Requires' => 1,
         'get_relationship_IsRoleOf' => 1,
@@ -601,6 +755,8 @@ sub _build_valid_methods
         'get_relationship_HasAsSequence' => 1,
         'get_relationship_IsSubInstanceOf' => 1,
         'get_relationship_Validates' => 1,
+        'get_relationship_IsSummarizedBy' => 1,
+        'get_relationship_Summarizes' => 1,
         'get_relationship_IsSuperclassOf' => 1,
         'get_relationship_IsSubclassOf' => 1,
         'get_relationship_IsTargetOf' => 1,
@@ -644,22 +800,32 @@ sub call_method {
     my $ctx = Bio::KBase::CDMI::ServiceContext->new(client_ip => $self->_plack_req->address);
     
     my $args = $data->{arguments};
-    if (@$args == 1 && ref($args->[0]) eq 'HASH')
-    {
-	my $actual_args = $args->[0]->{args};
-	my $token = $args->[0]->{auth_token};
-	$data->{arguments} = $actual_args;
-	
-	
+
         # Service CDMI_API does not require authentication.
-	
-    }
-    
+        
     my $new_isa = $self->get_package_isa($module);
     no strict 'refs';
     local @{"${module}::ISA"} = @$new_isa;
     local $CallContext = $ctx;
-    my @result = $module->$method(@{ $data->{arguments} });
+    my @result;
+    {
+	my $err;
+	eval {
+	    @result = $module->$method(@{ $data->{arguments} });
+	};
+	if ($@)
+	{
+	    #
+	    # Reraise the string version of the exception because
+	    # the RPC lib can't handle exception objects (yet).
+	    #
+	    my $err = $@;
+	    my $str = "$err";
+	    $str =~ s/Bio::KBase::CDMI::Service::call_method.*//s;
+	    $str =~ s/^/>\t/mg;
+	    die "The JSONRPC server invocation of the method \"$method\" failed with the following error:\n" . $str;
+	}
+    }
     my $result;
     if ($return_counts{$method} == 1)
     {
